# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waReporting/WAWebProtobufsReporting.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waReporting/WAWebProtobufsReporting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)waReporting/WAWebProtobufsReporting.proto\x12\x17WAWebProtobufsReporting\"d\n\nReportable\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\r\n\x05never\x18\x04 \x01(\x08\"\xa2\x01\n\x06\x43onfig\x12\x39\n\x05\x66ield\x18\x01 \x03(\x0b\x32*.WAWebProtobufsReporting.Config.FieldEntry\x12\x0f\n\x07version\x18\x02 \x01(\r\x1aL\n\nFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01\"\xf4\x01\n\x05\x46ield\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\x11\n\tisMessage\x18\x04 \x01(\x08\x12>\n\x08subfield\x18\x05 \x03(\x0b\x32,.WAWebProtobufsReporting.Field.SubfieldEntry\x1aO\n\rSubfieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01\x42\'Z%go.mau.fi/whatsmeow/proto/waReportingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waReporting.WAWebProtobufsReporting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%go.mau.fi/whatsmeow/proto/waReporting'
  _globals['_CONFIG_FIELDENTRY']._loaded_options = None
  _globals['_CONFIG_FIELDENTRY']._serialized_options = b'8\001'
  _globals['_FIELD_SUBFIELDENTRY']._loaded_options = None
  _globals['_FIELD_SUBFIELDENTRY']._serialized_options = b'8\001'
  _globals['_REPORTABLE']._serialized_start=70
  _globals['_REPORTABLE']._serialized_end=170
  _globals['_CONFIG']._serialized_start=173
  _globals['_CONFIG']._serialized_end=335
  _globals['_CONFIG_FIELDENTRY']._serialized_start=259
  _globals['_CONFIG_FIELDENTRY']._serialized_end=335
  _globals['_FIELD']._serialized_start=338
  _globals['_FIELD']._serialized_end=582
  _globals['_FIELD_SUBFIELDENTRY']._serialized_start=503
  _globals['_FIELD_SUBFIELDENTRY']._serialized_end=582
# @@protoc_insertion_point(module_scope)



from .proto import Neonize_pb2 as neonize
from .proto.waE2E.WAWebProtobufsE2E_pb2 import (
    Message,
    FutureProofMessage,
    ProtocolMessage,
    PeerDataOperationRequestMessage,
    PeerDataOperationRequestType,
)
from .proto.waCommon.WACommon_pb2 import MessageKey
from .const import DEFAULT_USER_SERVER
from .utils.jid import Jid2String, JIDToNonAD
import time


def build_edit(chat: neonize.JID, message_id: str, new_message: Message) -> Message:
    """
    This function builds an edited message in the WhatsApp protocol format.

    :param chat: The JID (Jabber ID) of the chat where the message will be sent.
    :type chat: neonize.JID
    :param message_id: The unique identifier of the message to be edited.
    :type message_id: str
    :param new_message: The new message content that will replace the old message.
    :type new_message: waProto.Message
    :return: The constructed message in the WhatsApp protocol format.
    :rtype: waProto.Message
    """
    return Message(
        editedMessage=FutureProofMessage(
            message=Message(
                protocolMessage=ProtocolMessage(
                    key=MessageKey(
                        fromMe=True,
                        ID=message_id,
                        remoteJID=Jid2String(chat),
                    ),
                    type=ProtocolMessage.MESSAGE_EDIT,
                    editedMessage=new_message,
                    timestampMS=int(time.time() * 1000),
                )
            )
        )
    )


def build_revoke(chat: neonize.JID, sender: neonize.JID, id: str, myJID: neonize.JID) -> Message:
    """
    This function builds and returns a protocol message of type 'REVOKE' with given parameters.

    :param chat: The chat ID where the message is to be revoked
    :type chat: neonize.JID
    :param sender: The sender's ID who is revoking the message
    :type sender: neonize.JID
    :param id: The ID of the message to be revoked
    :type id: str
    :param myJID: The ID of the user using the application
    :type myJID: neonize.JID
    :return: A protocol message of type 'REVOKE'
    :rtype: waProto.Message
    """
    msgKey = MessageKey(
        fromMe=myJID.User == sender.User,
        ID=id,
        remoteJID=Jid2String(chat),
    )
    if not sender.IsEmpty and not msgKey.fromMe and chat.Server != DEFAULT_USER_SERVER:
        msgKey.participant = Jid2String(JIDToNonAD(sender))
    return Message(protocolMessage=ProtocolMessage(type=ProtocolMessage.REVOKE, key=msgKey))


def build_history_sync_request(message_info: neonize.MessageInfo, count: int) -> Message:
    """
    Builds a history sync request message.

    :param message_info: Information about the message to sync from.
    :type message_info: neonize.MessageInfo
    :param count: Number of messages to sync.
    :type count: int
    :return: A constructed Message object for history sync.
    :rtype: Message
    """
    return Message(
        protocolMessage=ProtocolMessage(
            type=ProtocolMessage.PEER_DATA_OPERATION_REQUEST_MESSAGE,
            peerDataOperationRequestMessage=PeerDataOperationRequestMessage(
                peerDataOperationRequestType=PeerDataOperationRequestType.HISTORY_SYNC_ON_DEMAND,
                historySyncOnDemandRequest=PeerDataOperationRequestMessage.HistorySyncOnDemandRequest(
                    chatJID=Jid2String(message_info.MessageSource.Chat),
                    oldestMsgID=message_info.ID,
                    oldestMsgFromMe=message_info.MessageSource.IsFromMe,
                    onDemandMsgCount=count,
                    oldestMsgTimestampMS=message_info.Timestamp,
                ),
            ),
        )
    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MessageApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _ThreadType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ThreadTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MessageApplication.Metadata._ThreadType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DEFAULT: MessageApplication.Metadata._ThreadType.ValueType  # 0
            VANISH_MODE: MessageApplication.Metadata._ThreadType.ValueType  # 1
            DISAPPEARING_MESSAGES: MessageApplication.Metadata._ThreadType.ValueType  # 2

        class ThreadType(_ThreadType, metaclass=_ThreadTypeEnumTypeWrapper): ...
        DEFAULT: MessageApplication.Metadata.ThreadType.ValueType  # 0
        VANISH_MODE: MessageApplication.Metadata.ThreadType.ValueType  # 1
        DISAPPEARING_MESSAGES: MessageApplication.Metadata.ThreadType.ValueType  # 2

        @typing.final
        class QuotedMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            STANZAID_FIELD_NUMBER: builtins.int
            REMOTEJID_FIELD_NUMBER: builtins.int
            PARTICIPANT_FIELD_NUMBER: builtins.int
            PAYLOAD_FIELD_NUMBER: builtins.int
            stanzaID: builtins.str
            remoteJID: builtins.str
            participant: builtins.str
            @property
            def payload(self) -> global___MessageApplication.Payload: ...
            def __init__(
                self,
                *,
                stanzaID: builtins.str | None = ...,
                remoteJID: builtins.str | None = ...,
                participant: builtins.str | None = ...,
                payload: global___MessageApplication.Payload | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["participant", b"participant", "payload", b"payload", "remoteJID", b"remoteJID", "stanzaID", b"stanzaID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["participant", b"participant", "payload", b"payload", "remoteJID", b"remoteJID", "stanzaID", b"stanzaID"]) -> None: ...

        @typing.final
        class EphemeralSettingMap(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            CHATJID_FIELD_NUMBER: builtins.int
            EPHEMERALSETTING_FIELD_NUMBER: builtins.int
            chatJID: builtins.str
            @property
            def ephemeralSetting(self) -> global___MessageApplication.EphemeralSetting: ...
            def __init__(
                self,
                *,
                chatJID: builtins.str | None = ...,
                ephemeralSetting: global___MessageApplication.EphemeralSetting | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["chatJID", b"chatJID", "ephemeralSetting", b"ephemeralSetting"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["chatJID", b"chatJID", "ephemeralSetting", b"ephemeralSetting"]) -> None: ...

        CHATEPHEMERALSETTING_FIELD_NUMBER: builtins.int
        EPHEMERALSETTINGLIST_FIELD_NUMBER: builtins.int
        EPHEMERALSHAREDSECRET_FIELD_NUMBER: builtins.int
        FORWARDINGSCORE_FIELD_NUMBER: builtins.int
        ISFORWARDED_FIELD_NUMBER: builtins.int
        BUSINESSMETADATA_FIELD_NUMBER: builtins.int
        FRANKINGKEY_FIELD_NUMBER: builtins.int
        FRANKINGVERSION_FIELD_NUMBER: builtins.int
        QUOTEDMESSAGE_FIELD_NUMBER: builtins.int
        THREADTYPE_FIELD_NUMBER: builtins.int
        READONLYMETADATADATACLASS_FIELD_NUMBER: builtins.int
        GROUPID_FIELD_NUMBER: builtins.int
        GROUPSIZE_FIELD_NUMBER: builtins.int
        GROUPINDEX_FIELD_NUMBER: builtins.int
        BOTRESPONSEID_FIELD_NUMBER: builtins.int
        COLLAPSIBLEID_FIELD_NUMBER: builtins.int
        SECONDARYOTID_FIELD_NUMBER: builtins.int
        ephemeralSharedSecret: builtins.bytes
        forwardingScore: builtins.int
        isForwarded: builtins.bool
        frankingKey: builtins.bytes
        frankingVersion: builtins.int
        threadType: global___MessageApplication.Metadata.ThreadType.ValueType
        readonlyMetadataDataclass: builtins.str
        groupID: builtins.str
        groupSize: builtins.int
        groupIndex: builtins.int
        botResponseID: builtins.str
        collapsibleID: builtins.str
        secondaryOtid: builtins.str
        @property
        def chatEphemeralSetting(self) -> global___MessageApplication.EphemeralSetting: ...
        @property
        def ephemeralSettingList(self) -> global___MessageApplication.Metadata.EphemeralSettingMap: ...
        @property
        def businessMetadata(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def quotedMessage(self) -> global___MessageApplication.Metadata.QuotedMessage: ...
        def __init__(
            self,
            *,
            chatEphemeralSetting: global___MessageApplication.EphemeralSetting | None = ...,
            ephemeralSettingList: global___MessageApplication.Metadata.EphemeralSettingMap | None = ...,
            ephemeralSharedSecret: builtins.bytes | None = ...,
            forwardingScore: builtins.int | None = ...,
            isForwarded: builtins.bool | None = ...,
            businessMetadata: waCommon.WACommon_pb2.SubProtocol | None = ...,
            frankingKey: builtins.bytes | None = ...,
            frankingVersion: builtins.int | None = ...,
            quotedMessage: global___MessageApplication.Metadata.QuotedMessage | None = ...,
            threadType: global___MessageApplication.Metadata.ThreadType.ValueType | None = ...,
            readonlyMetadataDataclass: builtins.str | None = ...,
            groupID: builtins.str | None = ...,
            groupSize: builtins.int | None = ...,
            groupIndex: builtins.int | None = ...,
            botResponseID: builtins.str | None = ...,
            collapsibleID: builtins.str | None = ...,
            secondaryOtid: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["botResponseID", b"botResponseID", "businessMetadata", b"businessMetadata", "chatEphemeralSetting", b"chatEphemeralSetting", "collapsibleID", b"collapsibleID", "ephemeral", b"ephemeral", "ephemeralSettingList", b"ephemeralSettingList", "ephemeralSharedSecret", b"ephemeralSharedSecret", "forwardingScore", b"forwardingScore", "frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion", "groupID", b"groupID", "groupIndex", b"groupIndex", "groupSize", b"groupSize", "isForwarded", b"isForwarded", "quotedMessage", b"quotedMessage", "readonlyMetadataDataclass", b"readonlyMetadataDataclass", "secondaryOtid", b"secondaryOtid", "threadType", b"threadType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["botResponseID", b"botResponseID", "businessMetadata", b"businessMetadata", "chatEphemeralSetting", b"chatEphemeralSetting", "collapsibleID", b"collapsibleID", "ephemeral", b"ephemeral", "ephemeralSettingList", b"ephemeralSettingList", "ephemeralSharedSecret", b"ephemeralSharedSecret", "forwardingScore", b"forwardingScore", "frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion", "groupID", b"groupID", "groupIndex", b"groupIndex", "groupSize", b"groupSize", "isForwarded", b"isForwarded", "quotedMessage", b"quotedMessage", "readonlyMetadataDataclass", b"readonlyMetadataDataclass", "secondaryOtid", b"secondaryOtid", "threadType", b"threadType"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["ephemeral", b"ephemeral"]) -> typing.Literal["chatEphemeralSetting", "ephemeralSettingList", "ephemeralSharedSecret"] | None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CORECONTENT_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def coreContent(self) -> global___MessageApplication.Content: ...
        @property
        def signal(self) -> global___MessageApplication.Signal: ...
        @property
        def applicationData(self) -> global___MessageApplication.ApplicationData: ...
        @property
        def subProtocol(self) -> global___MessageApplication.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            coreContent: global___MessageApplication.Content | None = ...,
            signal: global___MessageApplication.Signal | None = ...,
            applicationData: global___MessageApplication.ApplicationData | None = ...,
            subProtocol: global___MessageApplication.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "coreContent", b"coreContent", "signal", b"signal", "subProtocol", b"subProtocol"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "coreContent", b"coreContent", "signal", b"signal", "subProtocol", b"subProtocol"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["coreContent", "signal", "applicationData", "subProtocol"] | None: ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONSUMERMESSAGE_FIELD_NUMBER: builtins.int
        BUSINESSMESSAGE_FIELD_NUMBER: builtins.int
        PAYMENTMESSAGE_FIELD_NUMBER: builtins.int
        MULTIDEVICE_FIELD_NUMBER: builtins.int
        VOIP_FIELD_NUMBER: builtins.int
        ARMADILLO_FIELD_NUMBER: builtins.int
        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        @property
        def consumerMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def businessMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def paymentMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def multiDevice(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def voip(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def armadillo(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            consumerMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            businessMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            paymentMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            multiDevice: waCommon.WACommon_pb2.SubProtocol | None = ...,
            voip: waCommon.WACommon_pb2.SubProtocol | None = ...,
            armadillo: waCommon.WACommon_pb2.SubProtocol | None = ...,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["armadillo", b"armadillo", "businessMessage", b"businessMessage", "consumerMessage", b"consumerMessage", "futureProof", b"futureProof", "multiDevice", b"multiDevice", "paymentMessage", b"paymentMessage", "subProtocol", b"subProtocol", "voip", b"voip"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["armadillo", b"armadillo", "businessMessage", b"businessMessage", "consumerMessage", b"consumerMessage", "futureProof", b"futureProof", "multiDevice", b"multiDevice", "paymentMessage", b"paymentMessage", "subProtocol", b"subProtocol", "voip", b"voip"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["subProtocol", b"subProtocol"]) -> typing.Literal["consumerMessage", "businessMessage", "paymentMessage", "multiDevice", "voip", "armadillo"] | None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class EphemeralSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _EphemeralityType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _EphemeralityTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MessageApplication.EphemeralSetting._EphemeralityType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: MessageApplication.EphemeralSetting._EphemeralityType.ValueType  # 0
            SEEN_ONCE: MessageApplication.EphemeralSetting._EphemeralityType.ValueType  # 1
            SEEN_BASED_WITH_TIMER: MessageApplication.EphemeralSetting._EphemeralityType.ValueType  # 2
            SEND_BASED_WITH_TIMER: MessageApplication.EphemeralSetting._EphemeralityType.ValueType  # 3

        class EphemeralityType(_EphemeralityType, metaclass=_EphemeralityTypeEnumTypeWrapper): ...
        UNKNOWN: MessageApplication.EphemeralSetting.EphemeralityType.ValueType  # 0
        SEEN_ONCE: MessageApplication.EphemeralSetting.EphemeralityType.ValueType  # 1
        SEEN_BASED_WITH_TIMER: MessageApplication.EphemeralSetting.EphemeralityType.ValueType  # 2
        SEND_BASED_WITH_TIMER: MessageApplication.EphemeralSetting.EphemeralityType.ValueType  # 3

        EPHEMERALEXPIRATION_FIELD_NUMBER: builtins.int
        EPHEMERALSETTINGTIMESTAMP_FIELD_NUMBER: builtins.int
        EPHEMERALITYTYPE_FIELD_NUMBER: builtins.int
        ISEPHEMERALSETTINGRESET_FIELD_NUMBER: builtins.int
        ephemeralExpiration: builtins.int
        ephemeralSettingTimestamp: builtins.int
        ephemeralityType: global___MessageApplication.EphemeralSetting.EphemeralityType.ValueType
        isEphemeralSettingReset: builtins.bool
        def __init__(
            self,
            *,
            ephemeralExpiration: builtins.int | None = ...,
            ephemeralSettingTimestamp: builtins.int | None = ...,
            ephemeralityType: global___MessageApplication.EphemeralSetting.EphemeralityType.ValueType | None = ...,
            isEphemeralSettingReset: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ephemeralExpiration", b"ephemeralExpiration", "ephemeralSettingTimestamp", b"ephemeralSettingTimestamp", "ephemeralityType", b"ephemeralityType", "isEphemeralSettingReset", b"isEphemeralSettingReset"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ephemeralExpiration", b"ephemeralExpiration", "ephemeralSettingTimestamp", b"ephemeralSettingTimestamp", "ephemeralityType", b"ephemeralityType", "isEphemeralSettingReset", b"isEphemeralSettingReset"]) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___MessageApplication.Payload: ...
    @property
    def metadata(self) -> global___MessageApplication.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___MessageApplication.Payload | None = ...,
        metadata: global___MessageApplication.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> None: ...

global___MessageApplication = MessageApplication



from .client import NewClient
from .utils.ffmpeg import FFmpeg
from .utils.iofile import TemporaryFile
from .events import Event
__version__ = '0.3.10.post6'
__all__ = ('NewClient', 'FFmpeg', 'TemporaryFile', 'Event')


import os
from pathlib import Path
import re
import tempfile
import typing
import io
import requests
import httpx
from .log import log
from typing import Optional

URL_MATCH = re.compile(r"^https?://")


def get_bytes_from_name_or_url(args: typing.Union[str, bytes]) -> bytes:
    """Gets bytes from either a file name or a URL.

    :param args: Either a file name (str) or binary data (bytes).
    :type args: typing.Union[str, bytes]
    :return: The bytes extracted from the specified file name or URL.
    :rtype: bytes
    """
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 "
        "(KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36",
    }
    if isinstance(args, str):
        if URL_MATCH.match(args):
            return requests.get(args, headers=headers).content
        else:
            with open(args, "rb") as file:
                return file.read()
    else:
        return args


async def get_bytes_from_name_or_url_async(args: typing.Union[str, bytes]) -> bytes:
    """Gets bytes from either a file name or a URL.

    :param args: Either a file name (str) or binary data (bytes).
    :type args: typing.Union[str, bytes]
    :return: The bytes extracted from the specified file name or URL.
    :rtype: bytes
    """
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 "
        "(KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36",
    }
    if isinstance(args, str):
        if URL_MATCH.match(args):
            async with httpx.AsyncClient(timeout=None) as client:
                return (await client.get(args, headers=headers)).content
        else:
            with open(args, "rb") as file:
                return file.read()
    else:
        return args


def write_from_bytesio_or_filename(fn_or_bytesio: typing.Union[io.BytesIO, str], data: bytes):
    """Writes bytes to either a BytesIO object or a file specified by its name.

    :param fn_or_bytesio: Either a BytesIO object or the name of the file to write data to.
    :type fn_or_bytesio: io.BytesIO | str
    :param data: The bytes to be written.
    :type data: bytes
    """
    if isinstance(fn_or_bytesio, io.BytesIO):
        fn_or_bytesio.write(data)
    else:
        with open(fn_or_bytesio, "wb") as file:
            file.write(data)


class TemporaryFile:
    def __init__(
        self,
        prefix: Optional[str] = None,
        suffix: Optional[str] = None,
        dir: Optional[str] = None,
        touch: bool = True,
    ) -> None:
        """
        Initializes a TemporaryFile object. This object represents a temporary file in the system.
        The file is created upon initialization and removed when the object is deleted.

        :param prefix: The prefix of the temporary file name, defaults to None
        :type prefix: Optional[str], optional
        :param suffix: The suffix of the temporary file name, defaults to None
        :type suffix: Optional[str], optional
        :param dir: The directory where the temporary file will be created, defaults to None
        :type dir: Optional[str], optional
        :param touch: If True, the file is immediately created upon object initialization, defaults to True
        :type touch: bool, optional
        """
        params = {}
        if prefix is not None:
            params["prefix"] = prefix
        if suffix is not None:
            params["suffix"] = suffix
        if dir is not None:
            params["dir"] = dir
        self.path = Path(tempfile.mktemp(**params))
        if touch:
            self.path.touch()

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        os.remove(self.path)
        log.debug("exc_type: %r, exc_value: %r, traceback: %r" % (exc_type, exc_value, traceback))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloICDC/WAArmadilloICDC.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloICDC/WAArmadilloICDC.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%waArmadilloICDC/WAArmadilloICDC.proto\x12\x0fWAArmadilloICDC\"_\n\x10ICDCIdentityList\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x64\x65vices\x18\x03 \x03(\x0c\x12\x1a\n\x12signingDeviceIndex\x18\x04 \x01(\x05\"<\n\x16SignedICDCIdentityList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x42+Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloICDC.WAArmadilloICDC_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC'
  _globals['_ICDCIDENTITYLIST']._serialized_start=58
  _globals['_ICDCIDENTITYLIST']._serialized_end=153
  _globals['_SIGNEDICDCIDENTITYLIST']._serialized_start=155
  _globals['_SIGNEDICDCIDENTITYLIST']._serialized_end=215
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MediaRetryNotification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ResultType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResultTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaRetryNotification._ResultType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GENERAL_ERROR: MediaRetryNotification._ResultType.ValueType  # 0
        SUCCESS: MediaRetryNotification._ResultType.ValueType  # 1
        NOT_FOUND: MediaRetryNotification._ResultType.ValueType  # 2
        DECRYPTION_ERROR: MediaRetryNotification._ResultType.ValueType  # 3

    class ResultType(_ResultType, metaclass=_ResultTypeEnumTypeWrapper): ...
    GENERAL_ERROR: MediaRetryNotification.ResultType.ValueType  # 0
    SUCCESS: MediaRetryNotification.ResultType.ValueType  # 1
    NOT_FOUND: MediaRetryNotification.ResultType.ValueType  # 2
    DECRYPTION_ERROR: MediaRetryNotification.ResultType.ValueType  # 3

    STANZAID_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    MESSAGESECRET_FIELD_NUMBER: builtins.int
    stanzaID: builtins.str
    directPath: builtins.str
    result: global___MediaRetryNotification.ResultType.ValueType
    messageSecret: builtins.bytes
    def __init__(
        self,
        *,
        stanzaID: builtins.str | None = ...,
        directPath: builtins.str | None = ...,
        result: global___MediaRetryNotification.ResultType.ValueType | None = ...,
        messageSecret: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["directPath", b"directPath", "messageSecret", b"messageSecret", "result", b"result", "stanzaID", b"stanzaID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["directPath", b"directPath", "messageSecret", b"messageSecret", "result", b"result", "stanzaID", b"stanzaID"]) -> None: ...

global___MediaRetryNotification = MediaRetryNotification

@typing.final
class ServerErrorReceipt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STANZAID_FIELD_NUMBER: builtins.int
    stanzaID: builtins.str
    def __init__(
        self,
        *,
        stanzaID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["stanzaID", b"stanzaID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["stanzaID", b"stanzaID"]) -> None: ...

global___ServerErrorReceipt = ServerErrorReceipt
